<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Brand;
use Illuminate\Support\Facades\File;

class BrandController extends Controller
{
    // Store a new brand
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'logo' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        $brand = new Brand();
        $brand->name = $request->name;

        // Handle logo upload
        if ($request->hasFile('logo')) {
            $image = $request->file('logo');
            $name = time() . '_' . $image->getClientOriginalName();
            $destinationPath = public_path('/uploads/brands');
            $image->move($destinationPath, $name);
            $brand->logo = $name;
        }

        $brand->save();

        return redirect()->back()->with('success', 'Brand added successfully.');
    }

    // Delete a brand
    public function destroy($id)
    {
        $brand = Brand::findOrFail($id);

        // Delete logo file if it exists
        if ($brand->logo && File::exists(public_path('uploads/brands/' . $brand->logo))) {
            File::delete(public_path('uploads/brands/' . $brand->logo));
        }

        $brand->delete();

        return redirect()->back()->with('success', 'Brand deleted successfully.');
    }
}
