<?php

namespace App\Http\Controllers;

use App\Models\Tag;
use App\Models\Plan;
use App\Models\User;
use App\Models\Grade;
use App\Models\Topic;
use App\Models\Student;
use App\Models\Subject;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Facades\Session;

class HomeController extends Controller
{

    // var $grades = null;
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        // $this->middleware('auth');
        $grades = Grade::where('status', 1)->where('show_front', 1)->get();
        $subjects = Subject::where('status', 1)->where('show_front', 1)->get();
        $topics = Topic::where('status', 1)->where('show_front', 1)->get();
        // $tags = Tag::get();
        View::share([
            'grades' => $grades,
            'subjects' => $subjects,
            'topics'  => $topics,
        ]);
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function home()
    {
        if (Auth::check() && Auth::user()->hasRole('superadmin')) {
            // Session::flash('success', 'Super Admin LoggedIn!');
            return redirect()->route('admin.dashboard');
        }

        if (Auth::check() && Auth::user()->hasRole('student')) {

            if(Auth::user()->student->status == 0)
            {
                Auth::logout();
                Session::flash('error', 'Account Not approved yet!');
                return redirect('/login');
            }
            // Session::flash('success', 'Super Admin LoggedIn!');
            return redirect('/');
        }

        Auth::logout();
        Session::flash('error', 'Something Went Wrong!');
        return redirect('/login'); // or any other route you want to redirect to
    }
    public function index()
    {
        $tags = Tag::where('status',1)->where('show_front',1)->get();
        $topics_top = Topic::where('status', 1)->limit(3)->get();
        $plans = Plan::where('status', 1)->where('show_front', 1)->get();
        // dd($topics_top);
        return view('front.index',['tags'=> $tags, 'topics_top'=> $topics_top, 'plans'=> $plans]);
    }

    public function about()
    {
        return view('front.about');
    }

    public function pricing()
    {
        $plans = Plan::where('status', 1)->get();
        return view('front.pricing',['plans'=> $plans]);
    }

    public function contact()
    {
        return view('front.contact');
    }

    public function students()
    {
        return view('front.students');
    }

    public function topicslist(Request $request)
    {
        $alltopics = Topic::get();
        $cgrade = $request->grade ?? null;
        $csubject = $request->subject ?? null;
        if($cgrade && $cgrade != null && $cgrade != 0)
        {
            $alltopics = $alltopics->where('grade_id', $cgrade);
        }
        if ($csubject && $csubject != null && $csubject != 0) {
            $alltopics = $alltopics->where('subject_id', $csubject);
        }

        $allgrades = Grade::where('status',1)->get();
        $allsubjects = Subject::where('status', 1)->get();
        return view('front.alltopics', ['alltopics' => $alltopics, 'csubject'=> $csubject,'cgrade'=>$cgrade, 'allgrades'=> $allgrades, 'allsubjects'=> $allsubjects]);
    }

    public function topic($slug)
    {
        if ($slug == null) {
            return redirect()->back();
        }

        $mytopic = Topic::where('slug', $slug)->first();
        $relateds = Topic::where('grade_id', $mytopic->grade_id)->orWhere('subject_id', $mytopic->subject_id)->get();
        // $fullContent = $mytopic->content;
        // $truncatedContent = $this->truncateHtml($fullContent, 40);
        // dd($truncatedContent);
        return view('front.topic', ['mytopic' => $mytopic, 'relateds'=> $relateds]);
    }

    private function truncateHtml($html, $percent)
    {
        $doc = new \DOMDocument();
        @$doc->loadHTML(mb_convert_encoding($html, 'HTML-ENTITIES', 'UTF-8'));

        $body = $doc->getElementsByTagName('body')->item(0);
        $totalLength = mb_strlen($body->textContent);
        $truncateLength = ceil($totalLength * $percent / 100);

        $truncatedContent = $this->truncateNode($body, $truncateLength);

        // Extract inner HTML from body tag
        $innerHTML = '';
        foreach ($truncatedContent->childNodes as $child) {
            $innerHTML .= $doc->saveHTML($child);
        }

        return $innerHTML;
    }

    private function truncateNode($node, $maxLength)
    {
        $currentLength = 0;
        $newNode = $node->cloneNode(false);

        foreach ($node->childNodes as $child) {
            if ($child->nodeType === XML_TEXT_NODE
            ) {
                if ($currentLength + mb_strlen($child->nodeValue) > $maxLength
                ) {
                    $newText = mb_substr($child->nodeValue, 0, $maxLength - $currentLength);
                    $newNode->appendChild(new \DOMText($newText));
                    break;
                } else {
                    $newNode->appendChild($child->cloneNode(true));
                    $currentLength += mb_strlen($child->nodeValue);
                }
            } else {
                $truncatedChild = $this->truncateNode($child, $maxLength - $currentLength);
                $newNode->appendChild($truncatedChild);
                $currentLength += mb_strlen($truncatedChild->textContent);
                if ($currentLength >= $maxLength) {
                    break;
                }
            }
        }

        return $newNode;
    }
    private function truncateContent($content)
{
    $length = strlen($content);
    $truncateLength = ceil($length * 0.40);
    return substr($content, 0, $truncateLength);
}

    public function registerstudent(Request $request)
    {
        $check = User::where('email', $request->email)->count();
        if ($check > 0) {
            Session::flash('error', 'Email already registered!');
            return redirect()->back();
        }

        $user = new User();
        $user->email = $request->email;
        $user->password = bcrypt($request->email);
        $user->name = $request->name;
        $user->save();

        $user->assignRole("student");

        $student = new Student();
        $student->email = $request->email;
        $student->guardian = $request->guardian;
        $student->name = $request->name;
        $student->school = $request->school;
        $student->grade_id = $request->grade_id;
        $student->contact = $request->contact;
        $student->country = $request->country;
        $student->city = $request->city;
        $student->remarks = $request->remarks;
        $student->user_id = $user->id;
        $student->status = 0;
        $student->save();

        Session::flash('success', 'You have been registered & after approval from our team you can then use your account!');
        return redirect()->back();
    }
}
