<?php

namespace App\Http\Controllers\admin;

use Carbon\Carbon;
use App\Models\Tag;
use App\Models\Plan;
use App\Models\Quiz;
use App\Models\User;
use App\Models\Grade;
use App\Models\Topic;
use App\Models\Student;
use App\Models\Subject;
use App\Models\FavTopic;
use App\Models\Question;
use App\Models\TopicTag;
use App\Models\QuizAttempt;
use App\Models\Transaction;
use Illuminate\Support\Str;
use App\Models\QuizQuestion;
use App\Models\Subscription;
use Illuminate\Http\Request;
use App\Models\TopicAttachment;
use App\Models\QuizAttemptAnswer;
use Spatie\Permission\Models\Role;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Session;
use Spatie\Permission\Models\Permission;


class StudentController extends Controller
{
    //
    public function _construct() {}


    public function dashboard()
    {

        return view('student.dashboard');
    }

    public function mytopics(Request $request)
    {
        $user = Auth::user();
        $student = $user->student;
        $topics = Topic::where('grade_id', $student->grade_id)->get();
        if ($request->subject && $request->subject != 0) {
            $topics = $topics->where('subject_id', $request->subject);
        }
        $subjects = Subject::where('status', 1)->get();
        return view('student.mytopics', ['topics' => $topics, 'subjects' => $subjects]);
    }

    public function favmytopics(Request $request)
    {
        $user = Auth::user();
        $student = $user->student;
        $topics = FavTopic::where('user_id', $user->id)->get();

        return view('student.favmytopics', ['topics' => $topics]);
    }

    public function topicdetails($id)
    {
        $topic = Topic::findOrFail($id);
        $user = Auth::user();
        if($topic->is_paid == 1 && $user->type != 1)
        {
            Session::flash('paid', 'Sorry You are not subscribed!');
            return redirect()->back();
        }
        return view('student.topicdetails', ['topic' => $topic]);
    }

    public function startquiz($id)
    {
        $quiz = Quiz::findOrFail($id);
        return view('student.startquiz', ['quiz' => $quiz]);
    }


    public function quiz($id)
    {
        $dt = Carbon::now();
        // $dt->toTimeString();
        $user = Auth::user();
        $quiz = Quiz::with('quizQuestions')->findOrFail($id);
        $newDateTime = Carbon::now()->addMinute($quiz->duration);
        // $newDateTime->toTimeString();
        $quizAttempt = QuizAttempt::create([
            'user_id' => $user->id,
            'quiz_id' => $quiz->id,
            'total_marks' => 0, // Will update this later
            'score' => 0, // Will update this later
            'correct_answers' => 0, // Will update this later
            'incorrect_answers' => 0, // Will update this later
            'start_time' =>  $dt,
            'end_time' => $newDateTime,
        ]);

        return redirect()->route('student.quizstartquiz',['quiz_id'=>$quiz->id, 'attempt_id'=> $quizAttempt->id]);

    }

    public function quizstartquiz($quiz_id,$attempt_id)
    {
        $user = Auth::user();
        $quiz = Quiz::with('quizQuestions')->findOrFail($quiz_id);
        $quizAttempt = QuizAttempt::where('id',$attempt_id)->first();
        $dt = Carbon::now();
        $time = $quiz->duration;
        // $dt->toTimeString();

        if($dt < $quizAttempt->end_time)
        {
            // $startTime = Carbon::parse('2024-09-12 14:30:00');
            $tt = Carbon::parse($quizAttempt->start_time);
            $minutesDifference = $tt->diffInMinutes($dt);
            // dd($minutesDifference);
            $time = $quiz->duration - $minutesDifference;
            // dd($time);
        }
        else
        {
            $time = 0.10;
        }
        // $duration = $quiz->duration;

        // dd($dt, $quizAttempt->start_time, $quizAttempt->end_time);
        return view('student.quiz', ['quiz' => $quiz ,'time'=>$time]);
    }
    public function submitquiz($id, Request $request)
    {
        // dd("hello");
        $quizId = $id;
        $user = auth()->user(); // Assuming the user is authenticated
        $quiz = Quiz::findOrFail($quizId);
        $totalMarks = 0;
        $correctAnswers = 0;
        $incorrectAnswers = 0;


        // Create a quiz attempt
        // Create a quiz attempt
        $quizAttempt = QuizAttempt::create([
            'user_id' => $user->id,
            'quiz_id' => $quiz->id,
            'total_marks' => 0, // Will update this later
            'score' => 0, // Will update this later
            'correct_answers' => 0, // Will update this later
            'incorrect_answers' => 0 // Will update this later
        ]);

        // Loop through each question and calculate the score
        foreach ($request->questions as $questionId => $questionData) {

            $question = Question::find($questionId);
            $userAnswer = $questionData['answer'] ?? '';
            $isCorrect = false;
            $marksAwarded = 0;
            // dd($quiz->quizQuestions);
            if($question->question_type->id == 3)
            {
                if($userAnswer == null)
                {
                    $userAnswer = [];
                }
                if(in_array($question->correct_answer, $userAnswer))
                {
                    $isCorrect = true;
                    $marksAwarded = $quiz->quiz_questions->where('question_id', $question->id)->first()->marks;
                    $correctAnswers++;
                }
                else{
                    $incorrectAnswers++;
                }
            }
            else{
            // Check if the answer is correct (case-insensitive)
            if (strcasecmp($question->correct_answer, $userAnswer) == 0) {
                $isCorrect = true;
                $marksAwarded = $quiz->quiz_questions->where('question_id', $question->id)->first()->marks;
                $correctAnswers++;
            } else {
                $incorrectAnswers++;
            }
        }

            // Save the user's answer
            QuizAttemptAnswer::create([
                'quiz_attempt_id' => $quizAttempt->id,
                'question_id' => $question->id,
                'answer' => is_array($userAnswer) ? json_encode($userAnswer) : $userAnswer,
                'is_correct' => $isCorrect,
                'marks_awarded' => $marksAwarded
            ]);

            $totalMarks += $marksAwarded;
        }

        // Update the quiz attempt with total marks and correct/incorrect answers
        $quizAttempt->update([
            'total_marks' => $totalMarks,
            'score' => $totalMarks,
            'correct_answers' => $correctAnswers,
            'incorrect_answers' => $incorrectAnswers
        ]);

        return redirect()->route('student.quiz.result', ['quizAttemptId' => $quizAttempt->id])
            ->with('success', 'Quiz submitted successfully!');
    }

    public function showResult($quizAttemptId)
    {
        $quizAttempt = QuizAttempt::with('quiz', 'answers.question')->findOrFail($quizAttemptId);
        return view('student.result', compact('quizAttempt'));
    }


    public function profileedit()
    {
        $user = Auth::user();
        $student = Student::where('user_id', $user->id)->first(); // Fetch student info by user_id

        return view('student.profile', compact('user', 'student'));
    }

    public function profileupdate(Request $request)
    {
        $user = Auth::user();
        $student = Student::where('user_id', $user->id)->firstOrFail();

        // Validate input
        $request->validate([
            'name' => 'required|string|max:255',
            'password' => 'nullable|min:8|confirmed', // Only validate password if filled
            'profile_picture' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'student_name' => 'required|string|max:255',
            'guardian' => 'required|string|max:255',
            'school' => 'required|string|max:255',
            'grade_id' => 'required|integer',
            'contact' => 'required|string|max:20',
            'address' => 'required|string',
            'city' => 'required|string|max:255',
            'country' => 'required|string|max:255',
        ]);

        // Update user profile
        $user->name = $request->name;

        if ($request->filled('password')) {
            $user->password = bcrypt($request->password);
        }

        // Handle profile picture upload
        if ($request->hasFile('profile_picture')) {
            if ($user->profile_picture && File::exists(public_path('uploads/profile_pictures/' . $user->profile_picture))) {
                File::delete(public_path('uploads/profile_pictures/' . $user->profile_picture));
            }

            $file = $request->file('profile_picture');
            $filename = time() . '_' . $file->getClientOriginalName();
            $file->move(public_path('uploads/profile_pictures'), $filename);
            $user->profile_picture = $filename;
        }

        $user->save();

        // Update student profile
        $student->name = $request->student_name;
        $student->guardian = $request->guardian;
        $student->school = $request->school;
        $student->grade_id = $request->grade_id;
        $student->contact = $request->contact;
        $student->address = $request->address;
        $student->city = $request->city;
        $student->country = $request->country;
        $student->save();

        return redirect()->back()->with('success', 'Profile updated successfully!');
    }

    public function listAttemptedQuizzes()
    {
        $user = auth()->user(); // Assuming the user is authenticated

        // Fetch all quiz attempts made by the user
        $quizAttempts = QuizAttempt::with(['quiz.topic'])
        ->where('user_id', $user->id)
        ->orderBy('created_at', 'desc')
        ->get();

        return view('student.quizattempt', compact('quizAttempts'));
    }

    public function favtopic($id,$status)
    {
        $user_id = Auth::user()->id;
        if($status == 0)
        {
            $fav = FavTopic::where('topic_id', $id)->where('user_id', $user_id)->first();
            $fav->delete();
        }
        if($status == 1)
        {
            $fav = new FavTopic();
            $fav->topic_id = $id;
            $fav->user_id = $user_id;
            $fav->save();
        }

        return redirect()->back()->with('success', 'updated successfully!');
    }

    public function subscribe($plan_id)
    {
        $user = Auth::user();
        $plan = Plan::findOrFail($plan_id);

        $subscription = new Subscription();
        $subscription->user_id = $user->id;
        $subscription->plan_id = $plan->id;
        $subscription->duration = $plan->duration;
        $subscription->plan_price = $plan->price;
        $subscription->status = 1;
        $subscription->save();

        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->plan_id = $plan->id;
        $transaction->duration = $plan->duration;
        $transaction->price = $plan->price;
        $transaction->response = "";
        $transaction->subscription_id = $subscription->id;
        $transaction->save();

        $user->type = 1;
        $user->save();

        Session::flash('success', 'Plan Subscribed!');
        return redirect()->route('student.dashboard');
    }

    public function checkout($plan_id)
    {
        $user = Auth::user();
        $plan = Plan::findOrFail($plan_id);


        return view('student.checkout',['plan'=>$plan]);
    }

    public function submitsubscription(Request $request)
    {
        $user = Auth::user();
        $plan = Plan::findOrFail($request->plan_id);

        $subscription = new Subscription();
        $subscription->user_id = $user->id;
        $subscription->plan_id = $plan->id;
        $subscription->duration = $plan->duration;
        $subscription->plan_price = $plan->price;
        $subscription->name = $request->name;
        $subscription->email = $request->email;
        $subscription->contact = $request->contact;
        $subscription->address = $request->address;
        $subscription->payment_type = $request->payment_method;
        $subscription->currency = getSetting('currency');
        $subscription->status = 0;

        if (isset($request->proof)) {
            $file = $request->file('proof');
            // Define the path to store the file
            $destinationPath = 'proofs';
            // Generate a unique name for the file
            $fileName = Str::random(16) . "-" . time() . '.' . $file->getClientOriginalExtension();
            // dd(public_path($destinationPath));
            // Move the file to the public directory
            $file->move(public_path($destinationPath), $fileName);

            $subscription->proof = $fileName;
        }


        $subscription->save();

        $transaction = new Transaction();
        $transaction->user_id = $user->id;
        $transaction->plan_id = $plan->id;
        $transaction->duration = $plan->duration;
        $transaction->price = $plan->price;
        $transaction->response = "";
        $transaction->subscription_id = $subscription->id;
        $transaction->save();

        $user->type = 2;
        $user->save();

        Session::flash('success', 'Plan Subscribed You are requested to wait for the approval!');
        return redirect()->route('student.dashboard');
    }

    public function cancelsubscription($id)
    {
        $subscription = Subscription::findOrFail($id);
        $subscription->status = 2;
        $subscription->save();

        $user = Auth::user();
        $user->type = 0;
        $user->save();

        Session::flash('success', 'Canceled');
        return redirect()->back();
    }
}
