@extends('layouts.admin')
@section('styles')
    <link rel="stylesheet" href="{{ asset('assets/richtexteditor/rte_theme_default.css') }}" />
@endsection

@section('content')
    <div class="page-wrapper">
        <!-- Page header -->
        <div class="page-header d-print-none">
            <div class="container-xl">
                <div class="row g-2 align-items-center">
                    <div class="col">
                        <h2 class="page-title">
                            New Questions
                        </h2>
                    </div>
                </div>
            </div>
        </div>
        <!-- Page body -->
        <div class="page-body">
            <div class="container-xl">

                <div class="row">

                    <div class="col-md-12">
                        <div class="card">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-12">
                                        <h2>Questions</h2>
                                    </div>
                                    <div class="col-md-12">
                                        <form id="quizForm" method="POST" action="{{ route('admin.savequestion')}}">
                                            @csrf
                                            <input type="hidden" name="count" id="count" value="0">
                                            <div class="row">
                                                <div class="col-md-12">
                                                    <label>Grade</label>
                                                    <select class="form-control" name="grade_id" required>
                                                        @foreach($grades as $grade)
                                                        <option value="{{$grade->id}}">{{$grade->title}}</option>
                                                        @endforeach
                                                    </select>
                                                </div>
                                                <div class="col-md-12">
                                                    <label>Subject</label>
                                                    <select class="form-control" name="subject_id" required>
                                                        @foreach($subjects as $subject)
                                                        <option value="{{$subject->id}}">{{$subject->title}}</option>
                                                        @endforeach
                                                    </select>
                                                </div>
                                            </div>
                                            <div id="questionsContainer"></div>
                                            <button type="button" class="btn btn-primary" id="addQuestionBtn">Add
                                                Question</button>
                                            <button type="submit" class="btn btn-success">Save Questions</button>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div>

        @include('includes.admin_footer')
    </div>
@endsection

@section('scripts')
    <script src="{{ asset('assets/admin/dist/libs/nouislider/dist/nouislider.min.js?1684106062') }}" defer></script>
    <script src="{{ asset('assets/admin/dist/libs/litepicker/dist/litepicker.js?1684106062') }}" defer></script>
    <script src="{{ asset('assets/admin/dist/libs/tom-select/dist/js/tom-select.base.min.js?1684106062') }}" defer></script>


    <script type="text/javascript" src="{{ asset('assets/richtexteditor/rte.js') }}"></script>
    <script type="text/javascript" src='{{ asset('assets/richtexteditor/plugins/all_plugins.js') }}'></script>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>

    <script>
        // @formatter:off
        document.addEventListener("DOMContentLoaded", function() {
            var el;
            window.TomSelect && (new TomSelect(el = document.getElementById('select-states'), {
                copyClassesToDropdown: false,
                dropdownParent: 'body',
                controlInput: '<input>',
                render: {
                    item: function(data, escape) {
                        if (data.customProperties) {
                            return '<div><span class="dropdown-item-indicator">' + data
                                .customProperties + '</span>' + escape(data.text) + '</div>';
                        }
                        return '<div>' + escape(data.text) + '</div>';
                    },
                    option: function(data, escape) {
                        if (data.customProperties) {
                            return '<div><span class="dropdown-item-indicator">' + data
                                .customProperties + '</span>' + escape(data.text) + '</div>';
                        }
                        return '<div>' + escape(data.text) + '</div>';
                    },
                },
            }));
        });
        // @formatter:on
    </script>

    <script>
        $(document).ready(function() {
            let questionCount = 0;

            $('#addQuestionBtn').click(function() {
                questionCount++;
                $("#count").val(questionCount);
                let questionHTML = `
                    <div class="card mb-3" id="question${questionCount}">
                        <div class="card-body">
                            <div class="form-group">
                                <label for="questionTitle${questionCount}">Question Title</label>
                                <input type="text" class="form-control" id="questionTitle${questionCount}" name="questionTitle${questionCount}" required>
                            </div>
                            <div class="form-group">
                                <label for="questionType${questionCount}">Question Type</label>
                                <select class="form-control questionType" id="questionType${questionCount}" name="questionType${questionCount}" data-question-id="${questionCount}" required>
                                    <option value="">Select Type</option>
                                    <option value="dropdown">Dropdown</option>
                                    <option value="checkbox">Checkbox</option>
                                    <option value="radio">Radio</option>
                                </select>
                            </div>
                            <div class="optionsContainer" id="optionsContainer${questionCount}"></div>
                            <div class="form-group">
                                <label for="correctAnswer${questionCount}">Correct Answer</label>
                                <input type="text" class="form-control" id="correctAnswer${questionCount}" name="correctAnswer${questionCount}" required>
                            </div>
                            <button type="button" class="btn btn-danger removeQuestionBtn" data-question-id="${questionCount}">Remove Question</button>
                        </div>
                    </div>
                `;
                $('#questionsContainer').append(questionHTML);
            });

            $('#questionsContainer').on('change', '.questionType', function() {
                let questionId = $(this).data('question-id');
                let questionType = $(this).val();
                let optionsContainer = $(`#optionsContainer${questionId}`);
                optionsContainer.empty();

                if (questionType === 'dropdown' || questionType === 'checkbox' || questionType ===
                    'radio') {
                    let optionHTML = `
                        <div class="form-group">
                            <label>Options</label>
                            <div class="input-group mb-3">
                                <input type="text" class="form-control optionInput" name="option${questionId}[]" required>
                                <div class="input-group-append">
                                    <button type="button" class="btn btn-outline-secondary addOptionBtn" data-question-id="${questionId}">Add Option</button>
                                </div>
                            </div>
                        </div>
                    `;
                    optionsContainer.append(optionHTML);
                }
            });

            $('#questionsContainer').on('click', '.addOptionBtn', function() {
                let questionId = $(this).data('question-id');
                let optionHTML = `
                    <div class="input-group mb-3">
                        <input type="text" class="form-control optionInput" name="option${questionId}[]" required>
                        <div class="input-group-append">
                            <button type="button" class="btn btn-outline-danger removeOptionBtn" data-question-id="${questionId}">Remove</button>
                        </div>
                    </div>
                `;
                $(`#optionsContainer${questionId}`).append(optionHTML);
            });

            $('#questionsContainer').on('click', '.removeOptionBtn', function() {
                $(this).closest('.input-group').remove();
            });

            $('#questionsContainer').on('click', '.removeQuestionBtn', function() {
                let questionId = $(this).data('question-id');
                $(`#question${questionId}`).remove();
                $("#count").val($("#count").val()-1);
            });

            // $('#quizForm').submit(function(e) {
            //     e.preventDefault();
            //     let quizData = $(this).serializeArray();
            //     console.log(quizData);
            //     alert('Quiz submitted! Check console for data.');
            // });
        });
    </script>
@endsection
