@extends('layouts.admin')

@section('content')
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-md-8">
                <div class="card">
                    <div class="card-header">Profile</div>

                    <div class="card-body">
                        @if (session('success'))
                            <div class="alert alert-success">
                                {{ session('success') }}
                            </div>
                        @endif

                        <form method="POST" action="{{ route('admin.profile.update') }}" enctype="multipart/form-data">
                            @csrf
                            @method('PUT')

                            <!-- Username -->
                            <div class="form-group mb-3">
                                <label for="name">Name</label>
                                <input id="name" type="text"
                                    class="form-control @error('name') is-invalid @enderror" name="name"
                                    value="{{ old('name', auth()->user()->name) }}" required autofocus>

                                @error('name')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                @enderror
                            </div>

                            <!-- Email (non-editable) -->
                            <div class="form-group mb-3">
                                <label for="email">Email (non-editable)</label>
                                <input id="email" type="email" class="form-control" name="email"
                                    value="{{ auth()->user()->email }}" disabled>
                            </div>

                            <!-- Password -->
                            <!-- Password -->
                            <div class="form-group mb-3">
                                <label for="password">New Password (leave blank if not changing)</label>
                                <input id="password" type="password"
                                    class="form-control @error('password') is-invalid @enderror" name="password">

                                @error('password')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                @enderror
                            </div>

                            <!-- Password Confirmation -->
                            <div class="form-group mb-3">
                                <label for="password-confirm">Confirm Password</label>
                                <input id="password-confirm" type="password" class="form-control"
                                    name="password_confirmation">
                            </div>


                            <!-- Profile Picture -->
                            <div class="form-group mb-3">
                                <label for="profile_picture">Profile Picture</label>
                                <input type="file" class="form-control @error('profile_picture') is-invalid @enderror"
                                    name="profile_picture">

                                @if (auth()->user()->profile_picture)
                                    <img src="{{ asset('uploads/profile_pictures/' . auth()->user()->profile_picture) }}"
                                        alt="Profile Picture" class="img-thumbnail mt-2" style="max-width: 150px;">
                                @endif

                                @error('profile_picture')
                                    <span class="invalid-feedback" role="alert">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                @enderror
                            </div>

                            <!-- Submit Button -->
                            <div class="form-group">
                                <button type="submit" class="btn btn-primary">
                                    Update Profile
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
