<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\BrandController;
use App\Http\Controllers\admin\AdminController;
use App\Http\Controllers\admin\StudentController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/



Route::get('/', [HomeController::class, 'index'])->name('front.index')->middleware('log.visitor');;
Route::get('/home', [HomeController::class, 'home'])->name('front.home')->middleware('log.visitor');;
Route::get('about', [HomeController::class, 'about'])->name('front.about')->middleware('log.visitor');;
Route::get('contact', [HomeController::class, 'contact'])->name('front.contact')->middleware('log.visitor');;

Route::get('topic/{slug}', [HomeController::class, 'topic'])->name('front.topic')->middleware('log.visitor');;
Route::get('topics-list', [HomeController::class, 'topicslist'])->name('front.topicslist')->middleware('log.visitor');;
Route::get('students', [HomeController::class, 'students'])->name('front.students')->middleware('log.visitor');;
Route::post('register-students', [HomeController::class, 'registerstudent'])->name('front.registerstudent')->middleware('log.visitor');;
Route::get('plan-pricing', [HomeController::class, 'pricing'])->name('front.pricing')->middleware('log.visitor');;


Route::prefix('student-portal')->group(function () {

    Route::group(['middleware' => ['student', 'auth']], function () {
        Route::get('dashboard', [StudentController::class, 'dashboard'])->name('student.dashboard');
        Route::get('mytopics', [StudentController::class, 'mytopics'])->name('student.mytopics');
        Route::get('fav-mytopics', [StudentController::class, 'favmytopics'])->name('student.favmytopics');
        Route::get('topicdetails/{id}', [StudentController::class, 'topicdetails'])->name('student.topicdetails');
        Route::get('startquiz/{id}', [StudentController::class, 'startquiz'])->name('student.startquiz');
        Route::get('quiz/{id}', [StudentController::class, 'quiz'])->name('student.quiz');
        Route::get('quiz-start-quiz/{quiz_id}/{attempt_id}', [StudentController::class, 'quizstartquiz'])->name('student.quizstartquiz');
        Route::post('quiz/submit/{id}', [StudentController::class, 'submitquiz'])->name('student.quizsubmit');
        Route::get('/quiz/result/{quizAttemptId}', [StudentController::class, 'showResult'])->name('student.quiz.result');
        Route::get('/profile', [StudentController::class, 'profileedit'])->name('student.profile.edit');
        // Handle profile update
        Route::put('/profile', [StudentController::class, 'profileupdate'])->name('student.profile.update');
        Route::get('/topic-fav/{id}/{status}', [StudentController::class, 'favtopic'])->name('student.favtopic');
        Route::get('my-quiz/attempts', [StudentController::class, 'listAttemptedQuizzes'])->name('student.quiz.attempts');

        Route::get('subscribe-membership/{id}', [StudentController::class, 'subscribe'])->name('student.subscribe');

        Route::get('cancel-subscription/{id}', [StudentController::class, 'cancelsubscription'])->name('student.cancelsubscription');
        Route::get('checkout-membership/{id}', [StudentController::class, 'checkout'])->name('student.checkout');
        Route::post('submit-subscription', [StudentController::class, 'submitsubscription'])->name('student.submitsubscription');
    });
});



Route::prefix('administrator')->group(function () {
    Route::get('login', [AdminController::class, 'login'])->name('admin.login');
    Route::get('signin', [AdminController::class, 'signin'])->name('admin.signin');

    Route::group(['middleware' => ['superadmin', 'auth']], function () {
        Route::get('dashboard', [AdminController::class, 'dashboard'])->name('admin.dashboard');
        Route::get('settings', [AdminController::class, 'settings'])->name('admin.settings');
        Route::post('admin/settings/update/{section}', [AdminController::class, 'update'])->name('admin.settings.update');
        Route::get('admin/quiz/result/{quizAttemptId}', [AdminController::class, 'showResult'])->name('admin.quiz.result');

        Route::get('admin/profile', [AdminController::class, 'profileedit'])->name('admin.profile');

        // Handle profile update
        Route::put('admin/profile', [AdminController::class, 'profileupdate'])->name('admin.profile.update');

        Route::post('/admin/settings/brands/store', [BrandController::class, 'store'])->name('brands.store');
        Route::delete('/admin/settings/brands/destroy/{id}', [BrandController::class, 'destroy'])->name('brands.destroy');


        Route::get('plans', [AdminController::class, 'plans'])->name('admin.plans');
        Route::get('new-plans', [AdminController::class, 'newplans'])->name('admin.newplans');
        Route::post('save-plans', [AdminController::class, 'saveplans'])->name('admin.saveplans');
        Route::get('pending-subscriptions', [AdminController::class, 'pendingsubscriptions'])->name('admin.pendingsubscriptions');
        Route::get('approved-subscriptions', [AdminController::class, 'approvedsubscriptions'])->name('admin.approvedsubscriptions');
        Route::get('expired-subscriptions', [AdminController::class, 'expiredsubscriptions'])->name('admin.expiredsubscriptions');
        Route::get('feature-plans/{id}/{status}', [AdminController::class, 'featureplans'])->name('admin.featureplans');
        Route::get('disable-plans/{id}/{status}', [AdminController::class, 'disableplans'])->name('admin.disableplans');
        Route::get('block-subscription/{id}/{status}', [AdminController::class, 'blocksubscription'])->name('admin.blocksubscription');

        Route::get('students', [AdminController::class, 'students'])->name('admin.students');
        Route::get('block-student/{id}/{status}', [AdminController::class, 'blockstudent'])->name('admin.blockstudent');
        Route::get('student-profile/{id}', [AdminController::class, 'studentprofile'])->name('admin.studentprofile');
        Route::put('/student/update-password', [AdminController::class, 'updatePassword'])->name('admin.student.updatePassword');

        Route::get('grades', [AdminController::class, 'grades'])->name('admin.grades');
        Route::post('save-grades', [AdminController::class, 'savegrades'])->name('admin.savegrades');
        Route::post('get-grades', [AdminController::class, 'getgrades'])->name('admin.getgrades');
        Route::post('update-grades', [AdminController::class, 'updategrades'])->name('admin.updategrades');
        Route::get('feature-grades/{id}/{status}', [AdminController::class, 'featuregrades'])->name('admin.featuregrades');
        Route::get('disable-grades/{id}/{status}', [AdminController::class, 'disablegrades'])->name('admin.disablegrades');
        Route::get('delete-grades/{id}', [AdminController::class, 'deletegrades'])->name('admin.deletegrades');



        Route::get('tags', [AdminController::class, 'tags'])->name('admin.tags');
        Route::post('save-tags', [AdminController::class, 'savetags'])->name('admin.savetags');
        Route::post('get-tags', [AdminController::class, 'gettags'])->name('admin.gettags');
        Route::post('update-tags', [AdminController::class, 'updatetags'])->name('admin.updatetags');
        Route::get('feature-tags/{id}/{status}', [AdminController::class, 'featuretags'])->name('admin.featuretags');
        Route::get('disable-tags/{id}/{status}', [AdminController::class, 'disabletags'])->name('admin.disabletags');
        Route::get('delete-tags/{id}', [AdminController::class, 'deletetags'])->name('admin.deletetags');


        Route::get('subjects', [AdminController::class, 'subjects'])->name('admin.subjects');
        Route::post('save-subjects', [AdminController::class, 'savesubjects'])->name('admin.savesubjects');
        Route::post('get-subjects', [AdminController::class, 'getsubjects'])->name('admin.getsubjects');
        Route::post('update-subjects', [AdminController::class, 'updatesubjects'])->name('admin.updatesubjects');
        Route::get('feature-subjects/{id}/{status}', [AdminController::class, 'featuresubjects'])->name('admin.featuresubjects');
        Route::get('disable-subjects/{id}/{status}', [AdminController::class, 'disablesubjects'])->name('admin.disablesubjects');
        Route::get('delete-subjects/{id}', [AdminController::class, 'deletesubjects'])->name('admin.deletesubjects');

        Route::get('topics', [AdminController::class, 'topics'])->name('admin.topics');
        Route::get('new-topic', [AdminController::class, 'newTopic'])->name('admin.newTopic');
        Route::post('save-topics', [AdminController::class, 'savetopics'])->name('admin.savetopics');
        Route::get('get-topics/{id}', [AdminController::class, 'gettopics'])->name('admin.gettopics');
        Route::post('update-topics', [AdminController::class, 'updatetopics'])->name('admin.updatetopics');

        Route::get('quiz', [AdminController::class, 'quiz'])->name('admin.quiz');
        Route::get('new-quiz', [AdminController::class, 'newQuiz'])->name('admin.newQuiz');
        Route::post('save-quiz', [AdminController::class, 'saveQuiz'])->name('admin.saveQuiz');

        Route::get('questions', [AdminController::class, 'questions'])->name('admin.questions');
        Route::get('new-questions', [AdminController::class, 'newQuestions'])->name('admin.newQuestions');
        Route::post('savequestion', [AdminController::class, 'savequestion'])->name('admin.savequestion');
        Route::post('getquestions', [AdminController::class, 'getquestions'])->name('admin.getquestions');

        Route::get('quiz/attempts', [AdminController::class, 'listAttemptedQuizzes'])->name('admin.quiz.attempts');

        Route::get('delete/file/{id}', [AdminController::class, 'deletefile'])->name('admin.deletefile');

        Route::get('delete-quiz/{quiz_id}/{id}', [AdminController::class, 'deletequiz'])->name('admin.deletequiz');
        Route::get('delete-question/{question_id}/{id}', [AdminController::class, 'deletequestion'])->name('admin.deletequestion');
        Route::get('show-quiz/{id}', [AdminController::class, 'showquiz'])->name('admin.showquiz');
    });
});

Auth::routes();
